@@ -3,12 +3,12 @@
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
 ##############################################################
-# Copyright (c) 2010 Christos Zamantzas
+# Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-Version = '0.8-7'
+Version = '0.8-8'
 
 import os
 import sys
@@ -489,11 +489,11 @@ class MyMainWindow(QtGui.QMainWindow):
        
        ##TAB: INIT
        def doInit(self):
-          os.system('sudo smscon -init')
+          os.system('sudo smscon -force init &')
           message = 'SMSCON has been initialised to the default configuration. \
                     \nThis editor will now quit...\n\nYou will need to open it again and edit your new configuration.'
           showMessage(message)
-          sys.exit(1)
+          sys.exit()
             
        def doReset(self):
           os.system('sudo smscon -reset')
@@ -604,9 +604,9 @@ class MyMainWindow(QtGui.QMainWindow):
              elif Line.startswith("ENABLERESEND "):
                 destination.write('ENABLERESEND      = \'%s\'\n' % EnableReply)
              elif Line.startswith("RESENDTIME "):
-                destination.write('RESENDTIME        = \'%s\'\n' % ReplyWait)
+                destination.write('RESENDTIME        = %s\n' % ReplyWait)
              #elif Line.startswith("MAXRESEND "):
-             #   destination.write('MAXRESEND         = \'%s\'\n' % ReplyAttempts)
+             #   destination.write('MAXRESEND        = %s\n' % ReplyAttempts)
              elif Line.startswith("SIMUNLOCK"):
                 destination.write('SIMUNLOCK         = \'%s\'\n' % NewSIMUnlock)
              elif Line.startswith("SILENCEDEVICE"):
